Base schema: "http://purl.allotrope.org/json-schemas/adm/spectrophotometry/REC/2024/06/spectrophotometry.schema"

Changes:

* Addition of fluorescence point measurment detection
  * Reasoning: proposed extension to the spectrophotometry model to support fluorescence measurement
  * Proposal: Request extension be reflected in the Allotrope schema